Identify track points that intersect with a barrier polygon
get_barrier_segments.RdThis function identifies the segments of consecutive points that intersect with the barrier polygon feature. The result is a tibble of segment records that identify portions of the track that will need to be re-routed.
Arguments
- trkpts
Simple Feature points ('sf', 'sfc_POINT'/'sfc_MULTIPOINT') that represent track points. Order is accepted as is and the bounding box of trkpts should be within the bounding box of the barrier polygon.
- barrier
Simple Feature polygon ('sf', 'sfc_POLYGON'/'sfc_MULTIPOLYGON') representing the barrier feature. Should be the same barrier as supplied to the
prt_visgraph()function.